@@ -108,7 +108,7 @@ class DatabaseManager:
         }
 
 
-        _cfu.writer.to_json("dbman_init.delete.json",{**self.data,**self.settings})
+        # _cfu.writer.to_json("dbman_init.delete.json",{**self.data,**self.settings})
 
         self.con = None
         self.cur = None
