@@ -57,6 +57,7 @@ class TableManager:
             'content_hash':None,
             'default_insert_data':[],
             'test_insert_data':[],
+            'comment':None,
         }
 
 
@@ -149,6 +150,7 @@ class TableManager:
         self.table_data = tb
         # f"{db_path}{schema_string}\\{table_name}"
         self.settings['db_path'] = db_path
+        # self.settings['comment'] = obj.get_arg(tb,['comment'],None,(int,float))
         self.settings['modified_timestamp'] = obj.get_arg(tb,['modified_timestamp'],time.time(),(int,float))
         self.settings['table_dir_path'] = obj.get_arg(tb,['table_dir_path'],f"{db_path}{schema_string}\\{table_name}",(str))
         self.settings['table_name'] = obj.get_arg(tb,['table_name'],table_name,(str))
@@ -180,6 +182,7 @@ class TableManager:
             f"{db_path}{schema_string}\\{table_name}\\{table_name}.test_data.json",
             (str))
         self.settings['raw_statement'] = obj.get_arg(tb,['raw_statement'],None,(str))
+        self.data['comment'] = obj.get_arg(tb,['comment'],None,(str))
         self.data['has_test_files'] = obj.get_arg(tb,['has_test_files'],None,(bool))
         self.data['columns'] = obj.get_arg(tb,['columns'],[],(list))
         self.data['primary_keys'] = obj.get_arg(tb,['primary_keys'],[],(list))
