@@ -21,7 +21,7 @@ from utils.type_utils.type_utils import *
 from utils.database_utils.DatabaseManager import *
 from utils.database_utils.TableDataManager import *
 from utils.database_utils.TableManager import *
-from utils.database_utils.drawio import *
+# from utils.database_utils.drawio import *
 
 
 
