@@ -652,6 +652,10 @@ def escape_quoted_chars(value,reverse=False,ignore=None):
     return value
 
 def parse_column_data(value=None):
+    print(f"parse_column_data")
+    match = _re.findall(r"\s+DEFAULT\s+([\'\"][^\']*[\'\"]|[0-9\.])",value,_re.IGNORECASE)
+    if match is not None:
+        print(f"default found: {match}")
     
     # value = "`timestamp`       int NULL DEFAULT NULL COMMENT 'Timestamp of when the task was created.' ,"
     _tick,_double_quote,_single_quote,_comma = [Suppress(x) for x in list('`"\',')]
@@ -671,13 +675,24 @@ def parse_column_data(value=None):
     null_vals = CaselessKeyword("NULL") | CaselessKeyword("NOT NULL")
     null_type = null_vals.setResultsName('null_type')
 
+
+
+
     def_k = Suppress(CaselessKeyword('DEFAULT'))
-    default = Optional(def_k + Word(alphanums))
+    def_val = Word(alphanums + ' \'\"`.-')
+    # def_int_val = Optional(_quote) + Word(nums + '.') + Optional(_quote)
+    default = Optional(def_k + def_val)
     quote = QuotedString("'", esc_quote="''",unquote_results=False).search_string(value)
     if len(quote) > 0:
+        print(f"default quote:{quote}")
         quote = quote[0][0]
         default = Optional(default|def_k + quote).setResultsName('default')
 
+
+
+
+
+
     com_k = Suppress(CaselessKeyword('COMMENT'))
     comment = Optional(com_k + Word(alphanums))
     quote = QuotedString("'", esc_quote="''",unquote_results=False).search_string(value)
